.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

TotalDepth.util.FileBuffer (Look-ahead File Buffer)
=====================================================

.. automodule:: TotalDepth.util.FileBuffer
	:member-order: bysource
	:members:
	:special-members:

